package com.test.service;

import android.os.Bundle;
import android.os.IBinder;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.google.android.material.snackbar.Snackbar;

import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;

import android.os.RemoteException;
import android.view.View;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import com.test.service.IMyAidlInterface;

public class MainActivity extends AppCompatActivity {
    private TextView mTextViewContent;
    private IMyAidlInterface mBoundService;
    private boolean isBound;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Toolbar toolbar = findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        FloatingActionButton fab = findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Snackbar.make(view, "Replace with your own action", Snackbar.LENGTH_LONG)
                        .setAction("Action", null).show();
            }
        });

        mTextViewContent = findViewById(R.id.textView_content);

        startService(new Intent(this, com.test.service.service.MyService.class));
        isBound = false;
        doBindService();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        doBindService();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    /**
     * Class for interacting with the main interface of the service.
     */
    private ServiceConnection mConnection = new ServiceConnection() {
        public void onServiceConnected(ComponentName className, IBinder service) {
            mBoundService = IMyAidlInterface.Stub.asInterface(service);

            String result = "Remote Service bind is failed !";
            try {
                result = mBoundService.getMessage();
            }catch (RemoteException e){
                e.printStackTrace();
            }
            mTextViewContent.setText(mTextViewContent.getText() + "\n" + result);
        }

        public void onServiceDisconnected(ComponentName className) {
            mBoundService = null;
            mTextViewContent.setText(mTextViewContent.getText() + "\n" + "Remote Service bind is disconnected");
        }
    };

    private void doBindService() {
        if (bindService(new Intent(MainActivity.this, com.test.service.service.MyService.class), mConnection, Context.BIND_AUTO_CREATE)) {
            isBound = true;
        }
    }

    private void doUnbindService() {
        if (isBound) {
            unbindService(mConnection);
            isBound = false;
        }
    }
}
